import { className, effect, template } from 'solid-js/web';
import hljs from 'highlight.js';
import { mergeProps, createMemo } from 'solid-js';

function escapeHtml(value) {
  return value.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#x27;");
}

const _tmpl$ = /*#__PURE__*/template(`<pre><code></code></pre>`, 4);

const Highlight = _props => {
  const props = mergeProps({
    autoDetect: true,
    ignoreIllegals: true,
    language: ""
  }, _props);
  const cannotDetectLanguage = !props.autoDetect && !props.language && !hljs.getLanguage(props.children);
  const className$1 = cannotDetectLanguage ? "" : `hljs ${props.language}`;
  const getHighlightedCode = createMemo(() => {
    if (cannotDetectLanguage) {
      console.warn(`The language "${props.language}" you specified could not be found.`);
      return escapeHtml(props.children);
    }

    if (props.autoDetect) {
      const result = hljs.highlightAuto(props.children);
      return result.value;
    } else {
      const result = hljs.highlight(props.children, {
        language: props.language,
        ignoreIllegals: props.ignoreIllegals
      });
      return result.value;
    }
  });
  return (() => {
    const _el$ = _tmpl$.cloneNode(true),
          _el$2 = _el$.firstChild;

    className(_el$2, className$1);

    effect(() => _el$2.innerHTML = getHighlightedCode());

    return _el$;
  })();
};

export { Highlight as default };
//# sourceMappingURL=index.js.map
